@@ -1,9 +1,9 @@
 #  LINEAR MODELS
 
-lmFit <- function(object,design=NULL,ndups=1,spacing=1,block=NULL,correlation,weights=NULL,method="ls",...)
+lmFit <- function(object,design=NULL,ndups=NULL,spacing=NULL,block=NULL,correlation,weights=NULL,method="ls",...)
 #	Fit genewise linear models
 #	Gordon Smyth
-#	30 June 2003.  Last modified 7 Aug 2020.
+#	30 June 2003.  Last modified 22 Nov 2020.
 {
 #	Extract components from y
 	y <- getEAWP(object)
@@ -21,14 +21,14 @@ lmFit <- function(object,design=NULL,ndups=1,spacing=1,block=NULL,correlation,we
 	ne <- nonEstimable(design)
 	if(!is.null(ne)) cat("Coefficients not estimable:",paste(ne,collapse=" "),"\n")
 
-#	Weights and spacing arguments can be specified in call or stored in y
-#	Precedence for these arguments is
-#	1. Specified in function call
-#	2. Stored in object
-#	3. Default values
-	if(missing(ndups) && !is.null(y$printer$ndups)) ndups <- y$printer$ndups
-	if(missing(spacing) && !is.null(y$printer$spacing)) spacing <- y$printer$spacing
-	if(missing(weights) && !is.null(y$weights)) weights <- y$weights
+#	Check ndups and spacing. Default to 1.
+	if(is.null(ndups)) ndups <- y$printer$ndups
+	if(is.null(ndups)) ndups <- 1
+	if(is.null(spacing)) spacing <- y$printer$spacing
+	if(is.null(spacing)) spacing <- 1
+
+#	Check weights
+	if(is.null(weights)) weights <- y$weights
 
 #	Check method
 	method <- match.arg(method,c("ls","robust"))
