@@ -40,6 +40,14 @@ plotMA.MArrayLM <- function(object, coef=ncol(object), xlab="Average log-express
 	plotWithHighlights(x=object$Amean,y=logFC,xlab=xlab,ylab=ylab,main=main,status=status,...)
 }
 
+plotMA.EListRaw <- function(object, array=1, xlab="Average log-expression", ylab="Expression log-ratio (this sample vs others)", main=colnames(object)[array], status=object$genes$Status, zero.weights=FALSE, ...)
+{
+	if(!is.null(object$Eb)) object$E <- object$E-object$Eb
+	object$E <- log2(object$E)
+	object <- new("EList",unclass(object))
+	plotMA(object, array=array, xlab=xlab, ylab=ylab, main=main, status=status, zero.weights=zero.weights, ...)
+}
+
 plotMA.EList <- function(object, array=1, xlab="Average log-expression", ylab="Expression log-ratio (this sample vs others)", main=colnames(object)[array], status=object$genes$Status, zero.weights=FALSE, ...)
 #	MA-plot with color coding for controls
 #	Gordon Smyth 7 April 2003, James Wettenhall 27 June 2003.
@@ -155,13 +163,3 @@ plotPrintTipLoess <- function(object,layout,array=1,span=0.4,...) {
 	df <- data.frame(y=object$M[,array],x=object$A[,array],gr=factor(gridc(layout)),gc=factor(layout$ngrid.r-gridr(layout)+1))
 	coplot(y~x|gr*gc,data=na.omit(df),xlab=c("A","Tip Column"),ylab=c("M","Tip Row"),pch=".",span=span,show.given=FALSE,panel=panel.smooth)
 }
-
-mdplot <- function(x,xlab="Mean",ylab="Difference",...)
-#	Mean-difference plot
-#	Gordon Smyth
-#	16 March 2005. Last modified 30 Sep 2014.
-{
-	d <- x[,1]-x[,2]
-	m <- (x[,1]+x[,2])/2
-	plotWithHighlights(x=m,y=d,xlab=xlab,ylab=ylab,...)
-}
